job ('pem-vmware-pricegroup-ui-deploy-to-environment') {
    wrappers {
      credentialsBinding {
               usernamePassword('GITHUB_USER', 'GITHUB_TOKEN', 'pem-github-token')
        usernamePassword('CLOUD_FOUNDRY_USERNAME', 'CLOUD_FOUNDRY_PASSWORD', 'cloudfoundry_credential_pemtransformer')    
      }
    }
    logRotator {
        numToKeep(7)
    }
    authorization {
        permission('hudson.model.Item.Build', 'PEM-FEDCI-PIPELINE-DEVTEAM')
    }

    parameters {
      stringParam('ARTIFACT_VERSION', '40', 'Artifact version number to deploy')
      choiceParam('TARGET_ENVIRONMENT', ['qa', 'showcase', 'training', 'e2e', 'pilot', 'performance'], 'Deploy to TDEV PCF Space')
      choiceParam('APP_MEMORY', ['1024' ,'2048'], 'Select the Amount of Memory Needed for your Application')
      choiceParam('INSTANCE_COUNT', ['1' ,'2'], 'Select the Number of Instances Needed for your Application')
    }
    environmentVariables {
      env('PCF_DEPLOY_GRADLE_URL', 'https://github.gapinc.com/plan/pem-gradle-allprojects-pcf-deploy')
      env('ARTIFACTORY_URL', 'http://artifactory.gapinc.dev/artifactory/local-non-prod')
      env('jarNameSwitch', '-Pjar_file=pem-pricegroup-ui-\${ARTIFACT_VERSION}.jar' )
      env('org_name', 'PT-PriceServices')
      env('pcf_api', 'https://api.sys.cfplatform.dev.phx.gaptech.com')
      env('preprodConfigUri', 'https://pem-vmware-spring-cloud-config-server.apps.cfplatform.dev.phx.gaptech.com/')

    }
    scm {
      git {
        remote {
          url('${PCF_DEPLOY_GRADLE_URL}.git')
          credentials('github_credential')
        }
        branch("master")
      }
    }
    properties {
        
   }
    steps {
      shell('wget -q \${ARTIFACTORY_URL}/com/gap/pem/pem-pricegroup-ui/${ARTIFACT_VERSION}/pem-pricegroup-ui-\${ARTIFACT_VERSION}.jar')
      gradle {
          useWrapper(true)
          makeExecutable(true)
          tasks('cfRename')
          switches('-g . -Papp_name=pem-pricegroup-ui -Papp_memory=${APP_MEMORY} -Ptarget_env=${TARGET_ENVIRONMENT} -Ppcf_api=${pcf_api} -Porg_name=${org_name}')
      }
      gradle {
        useWrapper(true)
        makeExecutable(true)
        tasks('cfDeploy')
        fromRootBuildScriptDir(true)
        switches('-g . -Papp_name=pem-pricegroup-ui -Papp_memory=${APP_MEMORY} -Ptarget_env=${TARGET_ENVIRONMENT} -Pjar_file=pem-pricegroup-ui-\${ARTIFACT_VERSION}.jar -Pcloud_config_uri=${preprodConfigUri} -Ppcf_api=${pcf_api} -Porg_name=${org_name} --info')
      }
      gradle {
        useWrapper(true)
        makeExecutable(true)
        tasks('cfHealth')
        fromRootBuildScriptDir(true)
        switches('-g . -Papp_name=pem-pricegroup-ui -Papp_memory=${APP_MEMORY} -Ptarget_env=${TARGET_ENVIRONMENT} -Ppcf_api=${pcf_api} -Porg_name=${org_name}')
      }
      gradle {
        useWrapper(true)
        makeExecutable(true)
        tasks('cfSwapDeployed')
        fromRootBuildScriptDir(true)
        switches('-g . -Papp_name=pem-pricegroup-ui -Papp_memory=${APP_MEMORY} -Ptarget_env=${TARGET_ENVIRONMENT} -Ppcf_api=${pcf_api} -Porg_name=${org_name}')
      }
      gradle {
        useWrapper(true)
        makeExecutable(true)
        tasks('cfUndeploy')
        switches('-g . -Papp_name=pem-pricegroup-ui -Papp_memory=${APP_MEMORY} -Ptarget_env=${TARGET_ENVIRONMENT} -Ppcf_api=${pcf_api} -Porg_name=${org_name}')
      }
      
      shell('rm -rf pem-pricegroup-ui-\${ARTIFACT_VERSION}.jar') 
     }
}
